==> haskell-vector-instances-3.4-85-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-1DPyUhlHEsEEcx7R52RRF9
key: vector-instances-3.4-1DPyUhlHEsEEcx7R52RRF9
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: aa3d7500fa36f777a920d75214bdd458
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-1DPyUhlHEsEEcx7R52RRF9
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    keys-3.12.1-GU3vuJ8aWOYEfNONz0R0BC
    pointed-5.0.1-6t8xLPIY4N15Zihr9MrOAi
    semigroupoids-5.3.1-HnAehqim391AnbE6GNyZx5
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             keys-3.12.1-GU3vuJ8aWOYEfNONz0R0BC=2517b04d8c6db60a0b349cd36d2e8082
             pointed-5.0.1-6t8xLPIY4N15Zihr9MrOAi=dad26bd2efa9745734ccfe859a8f58e9
             semigroupoids-5.3.1-HnAehqim391AnbE6GNyZx5=5a2fccf4d02ab283783d02328c35f83d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-87-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-6HBKbMu0W5b3L9J93WgInM
key: vector-instances-3.4-6HBKbMu0W5b3L9J93WgInM
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: f6dc409978bfe834459c66998be06f47
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-6HBKbMu0W5b3L9J93WgInM
depends:
    base-4.11.1.0 comonad-5.0.4-L245XbCBrgdLdCTrjWcxlI
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    keys-3.12.1-75BB1OLWKMcB35vr8qBOGN
    pointed-5.0.1-Aat8CAZk0JCEWy0rYiRT1l
    semigroupoids-5.3.1-JFiz7imMBI8JcKI58oF6q6
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-L245XbCBrgdLdCTrjWcxlI=c1b18d1ad3a461ac4c005c7be7c16723
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             keys-3.12.1-75BB1OLWKMcB35vr8qBOGN=2f1177dbfebf5f65029eade5ae0346de
             pointed-5.0.1-Aat8CAZk0JCEWy0rYiRT1l=4ab9b909fd7a9a2e46934ff09210160e
             semigroupoids-5.3.1-JFiz7imMBI8JcKI58oF6q6=68c87984e4148aa3978cb255236ab388
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
